@@ -466,9 +466,9 @@ class KVGarbageCollector(BaseGarbageCollector):
     def __init__(self, storage, **kwargs):
         super().__init__(
             storage,
+            async_transaction=False,
             **kwargs,
         )
-        self.async_transaction = False
 
     async def collect(self, conn):
         to_del = []
@@ -590,7 +590,6 @@ def matcher(txn, event_id_iterator, query_items: tuple, stats: dict):
             stats["index_hits"] += 1
         else:
             stats["index_misses"] += 1
-            print(repr(event_tuple))
 
 
 @functools.lru_cache()
